==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkTextActor.java <==
// java wrapper for vtkTextActor object
//

package vtk;
import vtk.*;

public class vtkTextActor extends vtkTexturedActor2D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ShallowCopy_2(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_2(id0); }

  private native void SetInput_3(String id0);
  public void SetInput(String id0)
    { SetInput_3(id0); }

  private native String GetInput_4();
  public String GetInput()
    { return GetInput_4(); }

  private native void SetMinimumSize_5(int id0,int id1);
  public void SetMinimumSize(int id0,int id1)
    { SetMinimumSize_5(id0,id1); }

  private native void SetMinimumSize_6(int id0[]);
  public void SetMinimumSize(int id0[])
    { SetMinimumSize_6(id0); }

  private native int[]  GetMinimumSize_7();
  public int[]  GetMinimumSize()
    { return GetMinimumSize_7(); }

  private native void SetMaximumLineHeight_8(double id0);
  public void SetMaximumLineHeight(double id0)
    { SetMaximumLineHeight_8(id0); }

  private native double GetMaximumLineHeight_9();
  public double GetMaximumLineHeight()
    { return GetMaximumLineHeight_9(); }

  private native void SetTextScaleMode_10(int id0);
  public void SetTextScaleMode(int id0)
    { SetTextScaleMode_10(id0); }

  private native int GetTextScaleModeMinValue_11();
  public int GetTextScaleModeMinValue()
    { return GetTextScaleModeMinValue_11(); }

  private native int GetTextScaleModeMaxValue_12();
  public int GetTextScaleModeMaxValue()
    { return GetTextScaleModeMaxValue_12(); }

  private native int GetTextScaleMode_13();
  public int GetTextScaleMode()
    { return GetTextScaleMode_13(); }

  private native void SetTextScaleModeToNone_14();
  public void SetTextScaleModeToNone()
    { SetTextScaleModeToNone_14(); }

  private native void SetTextScaleModeToProp_15();
  public void SetTextScaleModeToProp()
    { SetTextScaleModeToProp_15(); }

  private native void SetTextScaleModeToViewport_16();
  public void SetTextScaleModeToViewport()
    { SetTextScaleModeToViewport_16(); }

  private native void SetUseBorderAlign_17(int id0);
  public void SetUseBorderAlign(int id0)
    { SetUseBorderAlign_17(id0); }

  private native int GetUseBorderAlign_18();
  public int GetUseBorderAlign()
    { return GetUseBorderAlign_18(); }

  private native void UseBorderAlignOn_19();
  public void UseBorderAlignOn()
    { UseBorderAlignOn_19(); }

  private native void UseBorderAlignOff_20();
  public void UseBorderAlignOff()
    { UseBorderAlignOff_20(); }

  private native void SetAlignmentPoint_21(int id0);
  public void SetAlignmentPoint(int id0)
    { SetAlignmentPoint_21(id0); }

  private native int GetAlignmentPoint_22();
  public int GetAlignmentPoint()
    { return GetAlignmentPoint_22(); }

  private native void SetOrientation_23(double id0);
  public void SetOrientation(double id0)
    { SetOrientation_23(id0); }

  private native double GetOrientation_24();
  public double GetOrientation()
    { return GetOrientation_24(); }

  private native void SetTextProperty_25(vtkTextProperty id0);
  public void SetTextProperty(vtkTextProperty id0)
    { SetTextProperty_25(id0); }

  private native long GetTextProperty_26();
  public vtkTextProperty GetTextProperty() {
    long temp = GetTextProperty_26();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetBoundingBox_27(vtkViewport id0,double id1[]);
  public void GetBoundingBox(vtkViewport id0,double id1[])
    { GetBoundingBox_27(id0,id1); }

  private native void GetSize_28(vtkViewport id0,double id1[]);
  public void GetSize(vtkViewport id0,double id1[])
    { GetSize_28(id0,id1); }

  private native int SetConstrainedFontSize_29(vtkViewport id0,int id1,int id2);
  public int SetConstrainedFontSize(vtkViewport id0,int id1,int id2)
    { return SetConstrainedFontSize_29(id0,id1,id2); }

  private native int SetConstrainedFontSize_30(vtkTextActor id0,vtkViewport id1,int id2,int id3);
  public int SetConstrainedFontSize(vtkTextActor id0,vtkViewport id1,int id2,int id3)
    { return SetConstrainedFontSize_30(id0,id1,id2,id3); }

  private native void SetNonLinearFontScale_31(double id0,int id1);
  public void SetNonLinearFontScale(double id0,int id1)
    { SetNonLinearFontScale_31(id0,id1); }

  private native void ComputeScaledFont_32(vtkViewport id0);
  public void ComputeScaledFont(vtkViewport id0)
    { ComputeScaledFont_32(id0); }

  private native long GetScaledTextProperty_33();
  public vtkTextProperty GetScaledTextProperty() {
    long temp = GetScaledTextProperty_33();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double GetFontScale_34(vtkViewport id0);
  public double GetFontScale(vtkViewport id0)
    { return GetFontScale_34(id0); }

  private native void ReleaseGraphicsResources_35(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_35(id0); }

  private native int RenderOpaqueGeometry_36(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_36(id0); }

  private native int RenderTranslucentPolygonalGeometry_37(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_37(id0); }

  private native int RenderOverlay_38(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_38(id0); }

  private native int HasTranslucentPolygonalGeometry_39();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_39(); }

  public vtkTextActor() { super(); }

  public vtkTextActor(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkTextActor.java <==
// java wrapper for vtkTextActor object
//

package vtk;
import vtk.*;

public class vtkTextActor extends vtkTexturedActor2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ShallowCopy_2(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_2(id0); }

  private native void SetInput_3(String id0);
  public void SetInput(String id0)
    { SetInput_3(id0); }

  private native String GetInput_4();
  public String GetInput()
    { return GetInput_4(); }

  private native void SetMinimumSize_5(int id0,int id1);
  public void SetMinimumSize(int id0,int id1)
    { SetMinimumSize_5(id0,id1); }

  private native void SetMinimumSize_6(int id0[]);
  public void SetMinimumSize(int id0[])
    { SetMinimumSize_6(id0); }

  private native int[]  GetMinimumSize_7();
  public int[]  GetMinimumSize()
    { return GetMinimumSize_7(); }

  private native void SetMaximumLineHeight_8(double id0);
  public void SetMaximumLineHeight(double id0)
    { SetMaximumLineHeight_8(id0); }

  private native double GetMaximumLineHeight_9();
  public double GetMaximumLineHeight()
    { return GetMaximumLineHeight_9(); }

  private native void SetTextScaleMode_10(int id0);
  public void SetTextScaleMode(int id0)
    { SetTextScaleMode_10(id0); }

  private native int GetTextScaleModeMinValue_11();
  public int GetTextScaleModeMinValue()
    { return GetTextScaleModeMinValue_11(); }

  private native int GetTextScaleModeMaxValue_12();
  public int GetTextScaleModeMaxValue()
    { return GetTextScaleModeMaxValue_12(); }

  private native int GetTextScaleMode_13();
  public int GetTextScaleMode()
    { return GetTextScaleMode_13(); }

  private native void SetTextScaleModeToNone_14();
  public void SetTextScaleModeToNone()
    { SetTextScaleModeToNone_14(); }

  private native void SetTextScaleModeToProp_15();
  public void SetTextScaleModeToProp()
    { SetTextScaleModeToProp_15(); }

  private native void SetTextScaleModeToViewport_16();
  public void SetTextScaleModeToViewport()
    { SetTextScaleModeToViewport_16(); }

  private native void SetUseBorderAlign_17(int id0);
  public void SetUseBorderAlign(int id0)
    { SetUseBorderAlign_17(id0); }

  private native int GetUseBorderAlign_18();
  public int GetUseBorderAlign()
    { return GetUseBorderAlign_18(); }

  private native void UseBorderAlignOn_19();
  public void UseBorderAlignOn()
    { UseBorderAlignOn_19(); }

  private native void UseBorderAlignOff_20();
  public void UseBorderAlignOff()
    { UseBorderAlignOff_20(); }

  private native void SetAlignmentPoint_21(int id0);
  public void SetAlignmentPoint(int id0)
    { SetAlignmentPoint_21(id0); }

  private native int GetAlignmentPoint_22();
  public int GetAlignmentPoint()
    { return GetAlignmentPoint_22(); }

  private native void SetOrientation_23(double id0);
  public void SetOrientation(double id0)
    { SetOrientation_23(id0); }

  private native double GetOrientation_24();
  public double GetOrientation()
    { return GetOrientation_24(); }

  private native void SetTextProperty_25(vtkTextProperty id0);
  public void SetTextProperty(vtkTextProperty id0)
    { SetTextProperty_25(id0); }

  private native long GetTextProperty_26();
  public vtkTextProperty GetTextProperty() {
    long temp = GetTextProperty_26();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetBoundingBox_27(vtkViewport id0,double id1[]);
  public void GetBoundingBox(vtkViewport id0,double id1[])
    { GetBoundingBox_27(id0,id1); }

  private native void GetSize_28(vtkViewport id0,double id1[]);
  public void GetSize(vtkViewport id0,double id1[])
    { GetSize_28(id0,id1); }

  private native int SetConstrainedFontSize_29(vtkViewport id0,int id1,int id2);
  public int SetConstrainedFontSize(vtkViewport id0,int id1,int id2)
    { return SetConstrainedFontSize_29(id0,id1,id2); }

  private native int SetConstrainedFontSize_30(vtkTextActor id0,vtkViewport id1,int id2,int id3);
  public int SetConstrainedFontSize(vtkTextActor id0,vtkViewport id1,int id2,int id3)
    { return SetConstrainedFontSize_30(id0,id1,id2,id3); }

  private native void SetNonLinearFontScale_31(double id0,int id1);
  public void SetNonLinearFontScale(double id0,int id1)
    { SetNonLinearFontScale_31(id0,id1); }

  private native void ComputeScaledFont_32(vtkViewport id0);
  public void ComputeScaledFont(vtkViewport id0)
    { ComputeScaledFont_32(id0); }

  private native long GetScaledTextProperty_33();
  public vtkTextProperty GetScaledTextProperty() {
    long temp = GetScaledTextProperty_33();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double GetFontScale_34(vtkViewport id0);
  public double GetFontScale(vtkViewport id0)
    { return GetFontScale_34(id0); }

  private native void ReleaseGraphicsResources_35(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_35(id0); }

  private native int RenderOpaqueGeometry_36(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_36(id0); }

  private native int RenderTranslucentPolygonalGeometry_37(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_37(id0); }

  private native int RenderOverlay_38(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_38(id0); }

  private native int HasTranslucentPolygonalGeometry_39();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_39(); }

  public vtkTextActor() { super(); }

  public vtkTextActor(long id) { super(id); }
  public native long   VTKInit();

}
